@@ -300,7 +300,7 @@ sort_mod_pkg_calls <- function(tree_matches, pkg_or_mod = c("mod", "pkg")) {
   )
 
   attached_names <- get_nodes_text_by_type(tree_matches, node_names)
-  order_attached_names <- order(attached_names)
+  order_attached_names <- order(attached_names, method = "radix")
   attached_calls <- get_nodes_text_by_type(tree_matches, node_calls)
   comments <- get_nodes_text_by_type(tree_matches, "comment")
   names(attached_calls) <- comments
@@ -371,7 +371,7 @@ sort_func_calls <- function(call_with_funcs) {
   comments <- get_nodes_text_by_type(call_with_funcs, "comment")
   names(func_calls) <- comments
 
-  order_func_names <- order(func_names)
+  order_func_names <- order(func_names, method = "radix")
   list(
     pkg_mod_name = pkg_mod_name,
     funcs = func_calls[order_func_names]
@@ -495,10 +495,11 @@ find_box_lines <- function(source_text) {
 #' @keywords internal
 find_source_lines_to_retain <- function(source_file_lines, box_lines) {
   source_lines <- seq(1, length(source_file_lines))
-  empty_source_lines <- which(grepl(pattern = "^[:space:]*$", source_file_lines))
+  empty_source_lines <- which(grepl(pattern = "^[[:space:]]*$", source_file_lines))
   non_box_lines <- source_lines[!source_lines %in% box_lines$all]
   end_of_box_calls <- ifelse(
-    empty_source_lines[empty_source_lines > box_lines$max][1] == box_lines$max + 1,
+    !rlang::is_empty(empty_source_lines) &&
+      empty_source_lines[empty_source_lines > box_lines$max][1] == box_lines$max + 1,
     box_lines$max + 1,
     box_lines$max
   )
