@@ -29,6 +29,28 @@ test_that("get_attached_modules returns correct list of imported whole modules",
   expect_setequal(results$nested$module_b, module_b_objects)
 })
 
+test_that("get_attached_modules returns correct list of imported whole modules in separate calls", {
+  whole_imported_modules <- "
+  box::use(path/to/module_a)
+  box::use(alias = path/to/module_b, path/to/module_c)
+  "
+
+  xml_whole_imported_modules <- code_to_xml_expr(whole_imported_modules)
+  results <- get_attached_modules(xml_whole_imported_modules)
+  expected_results <- c("module_a", "alias", "module_c")
+
+  expect_equal(names(results$nested), expected_results)
+
+  module_a_objects <- c("a_fun_a", "a_fun_b")
+  expect_setequal(results$nested$module_a, module_a_objects)
+
+  module_b_objects <- c("b_fun_a", "b_fun_b", "b_obj_a")
+  expect_setequal(results$nested$alias, module_b_objects)
+
+  module_c_objects <- c("c_fun_a", "c_fun_b", "c_obj_a")
+  expect_setequal(results$nested$module_c, module_c_objects)
+})
+
 test_that("get_attached_modules does not return modules imported with '...'", {
   whole_imported_modules <- "
   box::use(
@@ -247,6 +269,26 @@ test_that("get_attached_mod_three_dots returns correct list of imported function
   expect_setequal(results$text, c(module_a_objects, module_b_objects))
 })
 
+test_that(
+  "get_attached_mod_three_dots returns correct list of imported functions in separate calls", {
+    three_dots_import <- "
+  box::use(path/to/module_a[...])
+  box::use(path/to/module_b[...])
+  "
+
+    xml_three_dots_modules <- code_to_xml_expr(three_dots_import)
+    results <- get_attached_mod_three_dots(xml_three_dots_modules)
+
+    module_a_objects <- c("a_fun_a", "a_fun_b")
+    module_b_objects <- c("b_fun_a", "b_fun_b", "b_obj_a")
+
+    expect_setequal(results$nested$module_a, module_a_objects)
+    expect_setequal(results$nested$module_b, module_b_objects)
+
+    expect_setequal(results$text, c(module_a_objects, module_b_objects))
+  }
+)
+
 test_that("get_attached_mod_three_dots does not return whole imported modules", {
   three_dots_import <- "
   box::use(
